History
=======

This script was `initially released in 2010
<https://kevin.deldycke.com/2010/08/maildir-deduplication-script-python/>`_, and
was living in a `messy GitHub repository
<https://github.com/kdeldycke/scripts>`_.

After some years, the script basically outgrew its initial intent, and `moved
in 2013 to its own repository
<https://kevin.deldycke.com/2013/06/maildir-deduplicate-moved/>`_.

It then continued to be updated as a stand-alone script before being properly
packaged into the current form. The last known working version of the
stand-alone script is available in the `legacy branch
<https://github.com/kdeldycke/maildir-deduplicate/tree/legacy>`_.
